==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardDashboardPublishOptionsSheetControlsOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsSheetControlsOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property visibilityState Visibility state. Possibles values: EXPANDED, COLLAPSED.
 */
public data class DashboardDashboardPublishOptionsSheetControlsOptionArgs(
    public val visibilityState: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsSheetControlsOptionArgs> {
    override fun toJava():
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsSheetControlsOptionArgs =
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsSheetControlsOptionArgs.builder()
            .visibilityState(visibilityState?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DashboardDashboardPublishOptionsSheetControlsOptionArgs].
 */
@PulumiTagMarker
public class DashboardDashboardPublishOptionsSheetControlsOptionArgsBuilder internal constructor() {
    private var visibilityState: Output<String>? = null

    /**
     * @param value Visibility state. Possibles values: EXPANDED, COLLAPSED.
     */
    @JvmName("liqlntibntmfgyoa")
    public suspend fun visibilityState(`value`: Output<String>) {
        this.visibilityState = value
    }

    /**
     * @param value Visibility state. Possibles values: EXPANDED, COLLAPSED.
     */
    @JvmName("qppbpcmlqwleboqc")
    public suspend fun visibilityState(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.visibilityState = mapped
    }

    internal fun build(): DashboardDashboardPublishOptionsSheetControlsOptionArgs =
        DashboardDashboardPublishOptionsSheetControlsOptionArgs(
            visibilityState = visibilityState,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardDashboardPublishOptionsSheetControlsOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsSheetControlsOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property visibilityState Visibility state. Possibles values: EXPANDED, COLLAPSED.
 */
public data class DashboardDashboardPublishOptionsSheetControlsOptionArgs(
    public val visibilityState: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsSheetControlsOptionArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsSheetControlsOptionArgs =
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsSheetControlsOptionArgs.builder()
            .visibilityState(visibilityState?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DashboardDashboardPublishOptionsSheetControlsOptionArgs].
 */
@PulumiTagMarker
public class DashboardDashboardPublishOptionsSheetControlsOptionArgsBuilder internal constructor() {
    private var visibilityState: Output<String>? = null

    /**
     * @param value Visibility state. Possibles values: EXPANDED, COLLAPSED.
     */
    @JvmName("lbiixuldxgtlufkk")
    public suspend fun visibilityState(`value`: Output<String>) {
        this.visibilityState = value
    }

    /**
     * @param value Visibility state. Possibles values: EXPANDED, COLLAPSED.
     */
    @JvmName("vukwbeomsxkoctsc")
    public suspend fun visibilityState(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.visibilityState = mapped
    }

    internal fun build(): DashboardDashboardPublishOptionsSheetControlsOptionArgs =
        DashboardDashboardPublishOptionsSheetControlsOptionArgs(
            visibilityState = visibilityState,
        )
}
